@@ -8,6 +8,7 @@ from sklearn.utils import check_random_state
 from sklearn.metrics.pairwise import pairwise_distances
 from sklearn.metrics.pairwise import pairwise_kernels
 
+
 def plot(func):
     random_state = check_random_state(0)
     one_core = []
@@ -25,12 +26,12 @@ def plot(func):
         func(X, n_jobs=-1)
         multi_core.append(time.time() - start)
 
-    plt.figure('scikit-learn parallel %s benchmark results' % func.__name__)
+    plt.figure("scikit-learn parallel %s benchmark results" % func.__name__)
     plt.plot(sample_sizes, one_core, label="one core")
     plt.plot(sample_sizes, multi_core, label="multi core")
-    plt.xlabel('n_samples')
-    plt.ylabel('Time (s)')
-    plt.title('Parallel %s' % func.__name__)
+    plt.xlabel("n_samples")
+    plt.ylabel("Time (s)")
+    plt.title("Parallel %s" % func.__name__)
     plt.legend()
 
 
@@ -41,6 +42,7 @@ def euclidean_distances(X, n_jobs):
 def rbf_kernels(X, n_jobs):
     return pairwise_kernels(X, metric="rbf", n_jobs=n_jobs, gamma=0.1)
 
+
 plot(euclidean_distances)
 plot(rbf_kernels)
 plt.show()
