@@ -43,7 +43,7 @@ Line #      Hits         Time  Per Hit   % Time  Line Contents
     60       300       381409   1271.4     97.1          clf.predict(X_test_sparse)
 """
 
-from scipy.sparse.csr import csr_matrix
+from scipy.sparse import csr_matrix
 import numpy as np
 from sklearn.linear_model import SGDRegressor
 from sklearn.metrics import r2_score
