@@ -9,15 +9,19 @@ LOG_DIR = "mnist_tsne_output"
 
 
 if __name__ == "__main__":
-    parser = argparse.ArgumentParser('Plot benchmark results for t-SNE')
+    parser = argparse.ArgumentParser("Plot benchmark results for t-SNE")
     parser.add_argument(
-        '--labels', type=str,
-        default=op.join(LOG_DIR, 'mnist_original_labels_10000.npy'),
-        help='1D integer numpy array for labels')
+        "--labels",
+        type=str,
+        default=op.join(LOG_DIR, "mnist_original_labels_10000.npy"),
+        help="1D integer numpy array for labels",
+    )
     parser.add_argument(
-        '--embedding', type=str,
-        default=op.join(LOG_DIR, 'mnist_sklearn_TSNE_10000.npy'),
-        help='2D float numpy array for embedded data')
+        "--embedding",
+        type=str,
+        default=op.join(LOG_DIR, "mnist_sklearn_TSNE_10000.npy"),
+        help="2D float numpy array for embedded data",
+    )
     args = parser.parse_args()
 
     X = np.load(args.embedding)
@@ -26,5 +30,5 @@ if __name__ == "__main__":
     for i in np.unique(y):
         mask = y == i
         plt.scatter(X[mask, 0], X[mask, 1], alpha=0.2, label=int(i))
-    plt.legend(loc='best')
+    plt.legend(loc="best")
     plt.show()
