@@ -35,11 +35,12 @@ policyholders.
     <http://dx.doi.org/10.2139/ssrn.3164764>`_
 
 """
-print(__doc__)
+
 # Authors: Christian Lorentzen <lorentzen.ch@gmail.com>
 #          Roman Yurchak <rth.yurchak@gmail.com>
 #          Olivier Grisel <olivier.grisel@ensta.org>
 # License: BSD 3 clause
+
 import numpy as np
 import matplotlib.pyplot as plt
 import pandas as pd
@@ -70,12 +71,15 @@ df
 
 df["Frequency"] = df["ClaimNb"] / df["Exposure"]
 
-print("Average Frequency = {}"
-      .format(np.average(df["Frequency"], weights=df["Exposure"])))
+print(
+    "Average Frequency = {}".format(np.average(df["Frequency"], weights=df["Exposure"]))
+)
 
-print("Fraction of exposure with zero claims = {0:.1%}"
-      .format(df.loc[df["ClaimNb"] == 0, "Exposure"].sum() /
-              df["Exposure"].sum()))
+print(
+    "Fraction of exposure with zero claims = {0:.1%}".format(
+        df.loc[df["ClaimNb"] == 0, "Exposure"].sum() / df["Exposure"].sum()
+    )
+)
 
 fig, (ax0, ax1, ax2) = plt.subplots(ncols=3, figsize=(16, 4))
 ax0.set_title("Number of claims")
@@ -100,20 +104,19 @@ from sklearn.compose import ColumnTransformer
 
 
 log_scale_transformer = make_pipeline(
-    FunctionTransformer(np.log, validate=False),
-    StandardScaler()
+    FunctionTransformer(np.log, validate=False), StandardScaler()
 )
 
 linear_model_preprocessor = ColumnTransformer(
     [
-        ("passthrough_numeric", "passthrough",
-            ["BonusMalus"]),
-        ("binned_numeric", KBinsDiscretizer(n_bins=10),
-            ["VehAge", "DrivAge"]),
-        ("log_scaled_numeric", log_scale_transformer,
-            ["Density"]),
-        ("onehot_categorical", OneHotEncoder(),
-            ["VehBrand", "VehPower", "VehGas", "Region", "Area"]),
+        ("passthrough_numeric", "passthrough", ["BonusMalus"]),
+        ("binned_numeric", KBinsDiscretizer(n_bins=10), ["VehAge", "DrivAge"]),
+        ("log_scaled_numeric", log_scale_transformer, ["Density"]),
+        (
+            "onehot_categorical",
+            OneHotEncoder(),
+            ["VehBrand", "VehPower", "VehGas", "Region", "Area"],
+        ),
     ],
     remainder="drop",
 )
@@ -137,11 +140,12 @@ from sklearn.model_selection import train_test_split
 
 df_train, df_test = train_test_split(df, test_size=0.33, random_state=0)
 
-dummy = Pipeline([
-    ("preprocessor", linear_model_preprocessor),
-    ("regressor", DummyRegressor(strategy='mean')),
-]).fit(df_train, df_train["Frequency"],
-       regressor__sample_weight=df_train["Exposure"])
+dummy = Pipeline(
+    [
+        ("preprocessor", linear_model_preprocessor),
+        ("regressor", DummyRegressor(strategy="mean")),
+    ]
+).fit(df_train, df_train["Frequency"], regressor__sample_weight=df_train["Exposure"])
 
 
 ##############################################################################
@@ -157,26 +161,38 @@ def score_estimator(estimator, df_test):
     """Score an estimator on the test set."""
     y_pred = estimator.predict(df_test)
 
-    print("MSE: %.3f" %
-          mean_squared_error(df_test["Frequency"], y_pred,
-                             sample_weight=df_test["Exposure"]))
-    print("MAE: %.3f" %
-          mean_absolute_error(df_test["Frequency"], y_pred,
-                              sample_weight=df_test["Exposure"]))
+    print(
+        "MSE: %.3f"
+        % mean_squared_error(
+            df_test["Frequency"], y_pred, sample_weight=df_test["Exposure"]
+        )
+    )
+    print(
+        "MAE: %.3f"
+        % mean_absolute_error(
+            df_test["Frequency"], y_pred, sample_weight=df_test["Exposure"]
+        )
+    )
 
     # Ignore non-positive predictions, as they are invalid for
     # the Poisson deviance.
     mask = y_pred > 0
     if (~mask).any():
         n_masked, n_samples = (~mask).sum(), mask.shape[0]
-        print(f"WARNING: Estimator yields invalid, non-positive predictions "
-              f" for {n_masked} samples out of {n_samples}. These predictions "
-              f"are ignored when computing the Poisson deviance.")
+        print(
+            "WARNING: Estimator yields invalid, non-positive predictions "
+            f" for {n_masked} samples out of {n_samples}. These predictions "
+            "are ignored when computing the Poisson deviance."
+        )
 
-    print("mean Poisson deviance: %.3f" %
-          mean_poisson_deviance(df_test["Frequency"][mask],
-                                y_pred[mask],
-                                sample_weight=df_test["Exposure"][mask]))
+    print(
+        "mean Poisson deviance: %.3f"
+        % mean_poisson_deviance(
+            df_test["Frequency"][mask],
+            y_pred[mask],
+            sample_weight=df_test["Exposure"][mask],
+        )
+    )
 
 
 print("Constant mean frequency evaluation:")
@@ -194,11 +210,12 @@ score_estimator(dummy, df_test)
 from sklearn.linear_model import Ridge
 
 
-ridge_glm = Pipeline([
-    ("preprocessor", linear_model_preprocessor),
-    ("regressor", Ridge(alpha=1e-6)),
-]).fit(df_train, df_train["Frequency"],
-       regressor__sample_weight=df_train["Exposure"])
+ridge_glm = Pipeline(
+    [
+        ("preprocessor", linear_model_preprocessor),
+        ("regressor", Ridge(alpha=1e-6)),
+    ]
+).fit(df_train, df_train["Frequency"], regressor__sample_weight=df_train["Exposure"])
 
 # %%
 # The Poisson deviance cannot be computed on non-positive values predicted by
@@ -227,12 +244,15 @@ from sklearn.linear_model import PoissonRegressor
 
 n_samples = df_train.shape[0]
 
-poisson_glm = Pipeline([
-    ("preprocessor", linear_model_preprocessor),
-    ("regressor", PoissonRegressor(alpha=1e-12, max_iter=300))
-])
-poisson_glm.fit(df_train, df_train["Frequency"],
-                regressor__sample_weight=df_train["Exposure"])
+poisson_glm = Pipeline(
+    [
+        ("preprocessor", linear_model_preprocessor),
+        ("regressor", PoissonRegressor(alpha=1e-12, max_iter=300)),
+    ]
+)
+poisson_glm.fit(
+    df_train, df_train["Frequency"], regressor__sample_weight=df_train["Exposure"]
+)
 
 print("PoissonRegressor evaluation:")
 score_estimator(poisson_glm, df_test)
@@ -264,20 +284,27 @@ from sklearn.preprocessing import OrdinalEncoder
 
 tree_preprocessor = ColumnTransformer(
     [
-        ("categorical", OrdinalEncoder(),
-            ["VehBrand", "VehPower", "VehGas", "Region", "Area"]),
-        ("numeric", "passthrough",
-            ["VehAge", "DrivAge", "BonusMalus", "Density"]),
+        (
+            "categorical",
+            OrdinalEncoder(),
+            ["VehBrand", "VehPower", "VehGas", "Region", "Area"],
+        ),
+        ("numeric", "passthrough", ["VehAge", "DrivAge", "BonusMalus", "Density"]),
     ],
     remainder="drop",
 )
-poisson_gbrt = Pipeline([
-    ("preprocessor", tree_preprocessor),
-    ("regressor", HistGradientBoostingRegressor(loss="poisson",
-                                                max_leaf_nodes=128)),
-])
-poisson_gbrt.fit(df_train, df_train["Frequency"],
-                 regressor__sample_weight=df_train["Exposure"])
+poisson_gbrt = Pipeline(
+    [
+        ("preprocessor", tree_preprocessor),
+        (
+            "regressor",
+            HistGradientBoostingRegressor(loss="poisson", max_leaf_nodes=128),
+        ),
+    ]
+)
+poisson_gbrt.fit(
+    df_train, df_train["Frequency"], regressor__sample_weight=df_train["Exposure"]
+)
 
 print("Poisson Gradient Boosted Trees evaluation:")
 score_estimator(poisson_gbrt, df_test)
@@ -298,14 +325,11 @@ score_estimator(poisson_gbrt, df_test)
 fig, axes = plt.subplots(nrows=2, ncols=4, figsize=(16, 6), sharey=True)
 fig.subplots_adjust(bottom=0.2)
 n_bins = 20
-for row_idx, label, df in zip(range(2),
-                              ["train", "test"],
-                              [df_train, df_test]):
-    df["Frequency"].hist(bins=np.linspace(-1, 30, n_bins),
-                         ax=axes[row_idx, 0])
+for row_idx, label, df in zip(range(2), ["train", "test"], [df_train, df_test]):
+    df["Frequency"].hist(bins=np.linspace(-1, 30, n_bins), ax=axes[row_idx, 0])
 
     axes[row_idx, 0].set_title("Data")
-    axes[row_idx, 0].set_yscale('log')
+    axes[row_idx, 0].set_yscale("log")
     axes[row_idx, 0].set_xlabel("y (observed Frequency)")
     axes[row_idx, 0].set_ylim([1e1, 5e5])
     axes[row_idx, 0].set_ylabel(label + " samples")
@@ -313,12 +337,13 @@ for row_idx, label, df in zip(range(2),
     for idx, model in enumerate([ridge_glm, poisson_glm, poisson_gbrt]):
         y_pred = model.predict(df)
 
-        pd.Series(y_pred).hist(bins=np.linspace(-1, 4, n_bins),
-                               ax=axes[row_idx, idx+1])
+        pd.Series(y_pred).hist(
+            bins=np.linspace(-1, 4, n_bins), ax=axes[row_idx, idx + 1]
+        )
         axes[row_idx, idx + 1].set(
             title=model[-1].__class__.__name__,
-            yscale='log',
-            xlabel="y_pred (predicted expected Frequency)"
+            yscale="log",
+            xlabel="y_pred (predicted expected Frequency)",
         )
 plt.tight_layout()
 
@@ -361,8 +386,7 @@ plt.tight_layout()
 from sklearn.utils import gen_even_slices
 
 
-def _mean_frequency_by_risk_group(y_true, y_pred, sample_weight=None,
-                                  n_bins=100):
+def _mean_frequency_by_risk_group(y_true, y_pred, sample_weight=None, n_bins=100):
     """Compare predictions and observations for bins ordered by y_pred.
 
     We order the samples by ``y_pred`` and split it in bins.
@@ -389,19 +413,14 @@ def _mean_frequency_by_risk_group(y_true, y_pred, sample_weight=None,
         average y_pred for each bin
     """
     idx_sort = np.argsort(y_pred)
-    bin_centers = np.arange(0, 1, 1/n_bins) + 0.5/n_bins
+    bin_centers = np.arange(0, 1, 1 / n_bins) + 0.5 / n_bins
     y_pred_bin = np.zeros(n_bins)
     y_true_bin = np.zeros(n_bins)
 
     for n, sl in enumerate(gen_even_slices(len(y_true), n_bins)):
         weights = sample_weight[idx_sort][sl]
-        y_pred_bin[n] = np.average(
-            y_pred[idx_sort][sl], weights=weights
-        )
-        y_true_bin[n] = np.average(
-            y_true[idx_sort][sl],
-            weights=weights
-        )
+        y_pred_bin[n] = np.average(y_pred[idx_sort][sl], weights=weights)
+        y_true_bin[n] = np.average(y_true[idx_sort][sl], weights=weights)
     return bin_centers, y_true_bin, y_pred_bin
 
 
@@ -409,27 +428,26 @@ print(f"Actual number of claims: {df_test['ClaimNb'].sum()}")
 fig, ax = plt.subplots(nrows=2, ncols=2, figsize=(12, 8))
 plt.subplots_adjust(wspace=0.3)
 
-for axi, model in zip(ax.ravel(), [ridge_glm, poisson_glm, poisson_gbrt,
-                                   dummy]):
+for axi, model in zip(ax.ravel(), [ridge_glm, poisson_glm, poisson_gbrt, dummy]):
     y_pred = model.predict(df_test)
     y_true = df_test["Frequency"].values
     exposure = df_test["Exposure"].values
     q, y_true_seg, y_pred_seg = _mean_frequency_by_risk_group(
-        y_true, y_pred, sample_weight=exposure, n_bins=10)
+        y_true, y_pred, sample_weight=exposure, n_bins=10
+    )
 
     # Name of the model after the estimator used in the last step of the
     # pipeline.
-    print(f"Predicted number of claims by {model[-1]}: "
-          f"{np.sum(y_pred * exposure):.1f}")
+    print(f"Predicted number of claims by {model[-1]}: {np.sum(y_pred * exposure):.1f}")
 
-    axi.plot(q, y_pred_seg, marker='x', linestyle="--", label="predictions")
-    axi.plot(q, y_true_seg, marker='o', linestyle="--", label="observations")
+    axi.plot(q, y_pred_seg, marker="x", linestyle="--", label="predictions")
+    axi.plot(q, y_true_seg, marker="o", linestyle="--", label="observations")
     axi.set_xlim(0, 1.0)
     axi.set_ylim(0, 0.5)
     axi.set(
         title=model[-1],
-        xlabel='Fraction of samples sorted by y_pred',
-        ylabel='Mean Frequency (y_pred)'
+        xlabel="Fraction of samples sorted by y_pred",
+        ylabel="Mean Frequency (y_pred)",
     )
     axi.legend()
 plt.tight_layout()
@@ -489,27 +507,27 @@ fig, ax = plt.subplots(figsize=(8, 8))
 
 for model in [dummy, ridge_glm, poisson_glm, poisson_gbrt]:
     y_pred = model.predict(df_test)
-    cum_exposure, cum_claims = lorenz_curve(df_test["Frequency"], y_pred,
-                                            df_test["Exposure"])
+    cum_exposure, cum_claims = lorenz_curve(
+        df_test["Frequency"], y_pred, df_test["Exposure"]
+    )
     gini = 1 - 2 * auc(cum_exposure, cum_claims)
     label = "{} (Gini: {:.2f})".format(model[-1], gini)
     ax.plot(cum_exposure, cum_claims, linestyle="-", label=label)
 
 # Oracle model: y_pred == y_test
-cum_exposure, cum_claims = lorenz_curve(df_test["Frequency"],
-                                        df_test["Frequency"],
-                                        df_test["Exposure"])
+cum_exposure, cum_claims = lorenz_curve(
+    df_test["Frequency"], df_test["Frequency"], df_test["Exposure"]
+)
 gini = 1 - 2 * auc(cum_exposure, cum_claims)
 label = "Oracle (Gini: {:.2f})".format(gini)
 ax.plot(cum_exposure, cum_claims, linestyle="-.", color="gray", label=label)
 
 # Random Baseline
-ax.plot([0, 1], [0, 1], linestyle="--", color="black",
-        label="Random baseline")
+ax.plot([0, 1], [0, 1], linestyle="--", color="black", label="Random baseline")
 ax.set(
     title="Lorenz curves by model",
-    xlabel='Cumulative proportion of exposure (from safest to riskiest)',
-    ylabel='Cumulative proportion of claims'
+    xlabel="Cumulative proportion of exposure (from safest to riskiest)",
+    ylabel="Cumulative proportion of claims",
 )
 ax.legend(loc="upper left")
 
