@@ -8,6 +8,7 @@ This example shows how to use
 errors.
 
 """
+
 from sklearn import datasets
 from sklearn.model_selection import cross_val_predict
 from sklearn import linear_model
@@ -22,7 +23,7 @@ predicted = cross_val_predict(lr, X, y, cv=10)
 
 fig, ax = plt.subplots()
 ax.scatter(y, predicted, edgecolors=(0, 0, 0))
-ax.plot([y.min(), y.max()], [y.min(), y.max()], 'k--', lw=4)
-ax.set_xlabel('Measured')
-ax.set_ylabel('Predicted')
+ax.plot([y.min(), y.max()], [y.min(), y.max()], "k--", lw=4)
+ax.set_xlabel("Measured")
+ax.set_ylabel("Predicted")
 plt.show()
