@@ -25,23 +25,31 @@ import scipy.sparse as sp
 from .. import __version__
 
 from ..utils import check_array, IS_PYPY
-from ..utils.validation import _deprecate_positional_args
 
 if not IS_PYPY:
     from ._svmlight_format_fast import _load_svmlight_file
 else:
+
     def _load_svmlight_file(*args, **kwargs):
         raise NotImplementedError(
-                'load_svmlight_file is currently not '
-                'compatible with PyPy (see '
-                'https://github.com/scikit-learn/scikit-learn/issues/11543 '
-                'for the status updates).')
+            "load_svmlight_file is currently not "
+            "compatible with PyPy (see "
+            "https://github.com/scikit-learn/scikit-learn/issues/11543 "
+            "for the status updates)."
+        )
 
 
-@_deprecate_positional_args
-def load_svmlight_file(f, *, n_features=None, dtype=np.float64,
-                       multilabel=False, zero_based="auto", query_id=False,
-                       offset=0, length=-1):
+def load_svmlight_file(
+    f,
+    *,
+    n_features=None,
+    dtype=np.float64,
+    multilabel=False,
+    zero_based="auto",
+    query_id=False,
+    offset=0,
+    length=-1,
+):
     """Load datasets in the svmlight / libsvm format into sparse CSR matrix
 
     This format is a text-based format, with one sample per line. It does
@@ -53,8 +61,8 @@ def load_svmlight_file(f, *, n_features=None, dtype=np.float64,
     This format is used as the default format for both svmlight and the
     libsvm command line programs.
 
-    Parsing a text based source can be expensive. When working on
-    repeatedly on the same dataset, it is recommended to wrap this
+    Parsing a text based source can be expensive. When repeatedly
+    working on the same dataset, it is recommended to wrap this
     loader with joblib.Memory.cache to store a memmapped backup of the
     CSR results of the first call and benefit from the near instantaneous
     loading of memmapped structures for the subsequent calls.
@@ -74,13 +82,13 @@ def load_svmlight_file(f, *, n_features=None, dtype=np.float64,
 
     Parameters
     ----------
-    f : {str, file-like, int}
+    f : str, file-like or int
         (Path to) a file to load. If a path ends in ".gz" or ".bz2", it will
         be uncompressed on the fly. If an integer is passed, it is assumed to
         be a file descriptor. A file-like or file descriptor will not be closed
         by this function. A file-like object must be opened in binary mode.
 
-    n_features : int or None
+    n_features : int, default=None
         The number of features to use. If None, it will be inferred. This
         argument is useful to load several files that are subsets of a
         bigger sliced dataset: each subset might not have examples of
@@ -89,15 +97,15 @@ def load_svmlight_file(f, *, n_features=None, dtype=np.float64,
         n_features is only required if ``offset`` or ``length`` are passed a
         non-default value.
 
-    dtype : numpy data type, default np.float64
+    dtype : numpy data type, default=np.float64
         Data type of dataset to be loaded. This will be the data type of the
         output numpy arrays ``X`` and ``y``.
 
-    multilabel : boolean, optional, default False
+    multilabel : bool, default=False
         Samples may have several labels each (see
         https://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/multilabel.html)
 
-    zero_based : boolean or "auto", optional, default "auto"
+    zero_based : bool or "auto", default="auto"
         Whether column indices in f are zero-based (True) or one-based
         (False). If column indices are one-based, they are transformed to
         zero-based to match Python/NumPy conventions.
@@ -109,15 +117,15 @@ def load_svmlight_file(f, *, n_features=None, dtype=np.float64,
         to ``zero_based=True`` to avoid having the heuristic check yield
         inconsistent results on different segments of the file.
 
-    query_id : boolean, default False
+    query_id : bool, default=False
         If True, will return the query_id array for each file.
 
-    offset : integer, optional, default 0
+    offset : int, default=0
         Ignore the offset first bytes by seeking forward, then
         discarding the following bytes up until the next new line
         character.
 
-    length : integer, optional, default -1
+    length : int, default=-1
         If strictly positive, stop reading any new line of data once the
         position in the file has reached the (offset + length) bytes threshold.
 
@@ -132,11 +140,10 @@ def load_svmlight_file(f, *, n_features=None, dtype=np.float64,
        query_id for each sample. Only returned when query_id is set to
        True.
 
-    See also
+    See Also
     --------
-    load_svmlight_files: similar function for loading multiple files in this
-                         format, enforcing the same number of features/columns
-                         on all of them.
+    load_svmlight_files : Similar function for loading multiple files in this
+        format, enforcing the same number of features/columns on all of them.
 
     Examples
     --------
@@ -153,13 +160,18 @@ def load_svmlight_file(f, *, n_features=None, dtype=np.float64,
 
         X, y = get_data()
     """
-    return tuple(load_svmlight_files([f], n_features=n_features,
-                                     dtype=dtype,
-                                     multilabel=multilabel,
-                                     zero_based=zero_based,
-                                     query_id=query_id,
-                                     offset=offset,
-                                     length=length))
+    return tuple(
+        load_svmlight_files(
+            [f],
+            n_features=n_features,
+            dtype=dtype,
+            multilabel=multilabel,
+            zero_based=zero_based,
+            query_id=query_id,
+            offset=offset,
+            length=length,
+        )
+    )
 
 
 def _gen_open(f):
@@ -171,42 +183,50 @@ def _gen_open(f):
     _, ext = os.path.splitext(f)
     if ext == ".gz":
         import gzip
+
         return gzip.open(f, "rb")
     elif ext == ".bz2":
         from bz2 import BZ2File
+
         return BZ2File(f, "rb")
     else:
         return open(f, "rb")
 
 
-def _open_and_load(f, dtype, multilabel, zero_based, query_id,
-                   offset=0, length=-1):
+def _open_and_load(f, dtype, multilabel, zero_based, query_id, offset=0, length=-1):
     if hasattr(f, "read"):
-        actual_dtype, data, ind, indptr, labels, query = \
-            _load_svmlight_file(f, dtype, multilabel, zero_based, query_id,
-                                offset, length)
+        actual_dtype, data, ind, indptr, labels, query = _load_svmlight_file(
+            f, dtype, multilabel, zero_based, query_id, offset, length
+        )
     else:
         with closing(_gen_open(f)) as f:
-            actual_dtype, data, ind, indptr, labels, query = \
-                _load_svmlight_file(f, dtype, multilabel, zero_based, query_id,
-                                    offset, length)
+            actual_dtype, data, ind, indptr, labels, query = _load_svmlight_file(
+                f, dtype, multilabel, zero_based, query_id, offset, length
+            )
 
     # convert from array.array, give data the right dtype
     if not multilabel:
         labels = np.frombuffer(labels, np.float64)
     data = np.frombuffer(data, actual_dtype)
     indices = np.frombuffer(ind, np.longlong)
-    indptr = np.frombuffer(indptr, dtype=np.longlong)   # never empty
+    indptr = np.frombuffer(indptr, dtype=np.longlong)  # never empty
     query = np.frombuffer(query, np.int64)
 
-    data = np.asarray(data, dtype=dtype)    # no-op for float{32,64}
+    data = np.asarray(data, dtype=dtype)  # no-op for float{32,64}
     return data, indices, indptr, labels, query
 
 
-@_deprecate_positional_args
-def load_svmlight_files(files, *, n_features=None, dtype=np.float64,
-                        multilabel=False, zero_based="auto", query_id=False,
-                        offset=0, length=-1):
+def load_svmlight_files(
+    files,
+    *,
+    n_features=None,
+    dtype=np.float64,
+    multilabel=False,
+    zero_based="auto",
+    query_id=False,
+    offset=0,
+    length=-1,
+):
     """Load dataset from multiple files in SVMlight format
 
     This function is equivalent to mapping load_svmlight_file over a list of
@@ -224,14 +244,14 @@ def load_svmlight_files(files, *, n_features=None, dtype=np.float64,
 
     Parameters
     ----------
-    files : iterable over {str, file-like, int}
+    files : array-like, dtype=str, file-like or int
         (Paths of) files to load. If a path ends in ".gz" or ".bz2", it will
         be uncompressed on the fly. If an integer is passed, it is assumed to
         be a file descriptor. File-likes and file descriptors will not be
         closed by this function. File-like objects must be opened in binary
         mode.
 
-    n_features : int or None
+    n_features : int, default=None
         The number of features to use. If None, it will be inferred from the
         maximum column index occurring in any of the files.
 
@@ -239,15 +259,15 @@ def load_svmlight_files(files, *, n_features=None, dtype=np.float64,
         in any of the input files, but setting it to a lower value will cause
         an exception to be raised.
 
-    dtype : numpy data type, default np.float64
+    dtype : numpy data type, default=np.float64
         Data type of dataset to be loaded. This will be the data type of the
         output numpy arrays ``X`` and ``y``.
 
-    multilabel : boolean, optional
+    multilabel : bool, default=False
         Samples may have several labels each (see
         https://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/multilabel.html)
 
-    zero_based : boolean or "auto", optional
+    zero_based : bool or "auto", default="auto"
         Whether column indices in f are zero-based (True) or one-based
         (False). If column indices are one-based, they are transformed to
         zero-based to match Python/NumPy conventions.
@@ -259,15 +279,15 @@ def load_svmlight_files(files, *, n_features=None, dtype=np.float64,
         to zero_based=True to avoid having the heuristic check yield
         inconsistent results on different segments of the file.
 
-    query_id : boolean, defaults to False
+    query_id : bool, default=False
         If True, will return the query_id array for each file.
 
-    offset : integer, optional, default 0
+    offset : int, default=0
         Ignore the offset first bytes by seeking forward, then
         discarding the following bytes up until the next new line
         character.
 
-    length : integer, optional, default -1
+    length : int, default=-1
         If strictly positive, stop reading any new line of data once the
         position in the file has reached the (offset + length) bytes threshold.
 
@@ -287,7 +307,7 @@ def load_svmlight_files(files, *, n_features=None, dtype=np.float64,
     number of features (X_train.shape[1] == X_test.shape[1]). This may not
     be the case if you load the files individually with load_svmlight_file.
 
-    See also
+    See Also
     --------
     load_svmlight_file
     """
@@ -297,16 +317,26 @@ def load_svmlight_files(files, *, n_features=None, dtype=np.float64,
         zero_based = True
 
     if (offset != 0 or length > 0) and n_features is None:
-        raise ValueError(
-            "n_features is required when offset or length is specified.")
+        raise ValueError("n_features is required when offset or length is specified.")
 
-    r = [_open_and_load(f, dtype, multilabel, bool(zero_based), bool(query_id),
-                        offset=offset, length=length)
-         for f in files]
+    r = [
+        _open_and_load(
+            f,
+            dtype,
+            multilabel,
+            bool(zero_based),
+            bool(query_id),
+            offset=offset,
+            length=length,
+        )
+        for f in files
+    ]
 
-    if (zero_based is False or
-            zero_based == "auto" and all(len(tmp[1]) and np.min(tmp[1]) > 0
-                                         for tmp in r)):
+    if (
+        zero_based is False
+        or zero_based == "auto"
+        and all(len(tmp[1]) and np.min(tmp[1]) > 0 for tmp in r)
+    ):
         for _, indices, _, _, _ in r:
             indices -= 1
 
@@ -315,9 +345,11 @@ def load_svmlight_files(files, *, n_features=None, dtype=np.float64,
     if n_features is None:
         n_features = n_f
     elif n_features < n_f:
-        raise ValueError("n_features was set to {},"
-                         " but input file contains {} features"
-                         .format(n_features, n_f))
+        raise ValueError(
+            "n_features was set to {}, but input file contains {} features".format(
+                n_features, n_f
+            )
+        )
 
     result = []
     for data, indices, indptr, y, query_values in r:
@@ -334,12 +366,12 @@ def load_svmlight_files(files, *, n_features=None, dtype=np.float64,
 def _dump_svmlight(X, y, f, multilabel, one_based, comment, query_id):
     X_is_sp = int(hasattr(X, "tocsr"))
     y_is_sp = int(hasattr(y, "tocsr"))
-    if X.dtype.kind == 'i':
+    if X.dtype.kind == "i":
         value_pattern = "%d:%d"
     else:
         value_pattern = "%d:%.16g"
 
-    if y.dtype.kind == 'i':
+    if y.dtype.kind == "i":
         label_pattern = "%d"
     else:
         label_pattern = "%.16g"
@@ -350,10 +382,14 @@ def _dump_svmlight(X, y, f, multilabel, one_based, comment, query_id):
     line_pattern += " %s\n"
 
     if comment:
-        f.write(("# Generated by dump_svmlight_file from scikit-learn %s\n"
-                % __version__).encode())
-        f.write(("# Column indices are %s-based\n"
-                % ["zero", "one"][one_based]).encode())
+        f.write(
+            (
+                "# Generated by dump_svmlight_file from scikit-learn %s\n" % __version__
+            ).encode()
+        )
+        f.write(
+            ("# Column indices are %s-based\n" % ["zero", "one"][one_based]).encode()
+        )
 
         f.write(b"#\n")
         f.writelines(b"# %s\n" % line for line in comment.splitlines())
@@ -385,13 +421,12 @@ def _dump_svmlight(X, y, f, multilabel, one_based, comment, query_id):
         else:
             feat = (labels_str, s)
 
-        f.write((line_pattern % feat).encode('ascii'))
+        f.write((line_pattern % feat).encode("ascii"))
 
 
-@_deprecate_positional_args
-def dump_svmlight_file(X, y, f, *, zero_based=True, comment=None,
-                       query_id=None,
-                       multilabel=False):
+def dump_svmlight_file(
+    X, y, f, *, zero_based=True, comment=None, query_id=None, multilabel=False
+):
     """Dump the dataset in svmlight / libsvm file format.
 
     This format is a text-based format, with one sample per line. It does
@@ -403,24 +438,24 @@ def dump_svmlight_file(X, y, f, *, zero_based=True, comment=None,
     Parameters
     ----------
     X : {array-like, sparse matrix} of shape (n_samples, n_features)
-        Training vectors, where n_samples is the number of samples and
-        n_features is the number of features.
+        Training vectors, where `n_samples` is the number of samples and
+        `n_features` is the number of features.
 
     y : {array-like, sparse matrix}, shape = [n_samples (, n_labels)]
         Target values. Class labels must be an
         integer or float, or array-like objects of integer or float for
         multilabel classifications.
 
-    f : string or file-like in binary mode
+    f : str or file-like in binary mode
         If string, specifies the path that will contain the data.
         If file-like, data will be written to f. f should be opened in binary
         mode.
 
-    zero_based : boolean, optional
+    zero_based : bool, default=True
         Whether column indices should be written zero-based (True) or one-based
         (False).
 
-    comment : string, optional
+    comment : str, default=None
         Comment to insert at the top of the file. This should be either a
         Unicode string, which will be encoded as UTF-8, or an ASCII byte
         string.
@@ -428,13 +463,13 @@ def dump_svmlight_file(X, y, f, *, zero_based=True, comment=None,
         the file as having been dumped by scikit-learn. Note that not all
         tools grok comments in SVMlight files.
 
-    query_id : array-like of shape (n_samples,)
+    query_id : array-like of shape (n_samples,), default=None
         Array containing pairwise preference constraints (qid in svmlight
         format).
 
-    multilabel : boolean, optional
+    multilabel : bool, default=False
         Samples may have several labels each (see
-        https://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/multilabel.html)
+        https://www.csie.ntu.edu.tw/~cjlin/libsvmtools/datasets/multilabel.html).
 
         .. versionadded:: 0.17
            parameter *multilabel* to support multilabel datasets.
@@ -443,7 +478,6 @@ def dump_svmlight_file(X, y, f, *, zero_based=True, comment=None,
         # Convert comment string to list of lines in UTF-8.
         # If a byte string is passed, then check whether it's ASCII;
         # if a user wants to get fancy, they'll have to decode themselves.
-        # Avoid mention of str and unicode types for Python 3.x compat.
         if isinstance(comment, bytes):
             comment.decode("ascii")  # just for the exception
         else:
@@ -451,21 +485,21 @@ def dump_svmlight_file(X, y, f, *, zero_based=True, comment=None,
         if b"\0" in comment:
             raise ValueError("comment string contains NUL byte")
 
-    yval = check_array(y, accept_sparse='csr', ensure_2d=False)
+    yval = check_array(y, accept_sparse="csr", ensure_2d=False)
     if sp.issparse(yval):
         if yval.shape[1] != 1 and not multilabel:
-            raise ValueError("expected y of shape (n_samples, 1),"
-                             " got %r" % (yval.shape,))
+            raise ValueError(
+                "expected y of shape (n_samples, 1), got %r" % (yval.shape,)
+            )
     else:
         if yval.ndim != 1 and not multilabel:
-            raise ValueError("expected y of shape (n_samples,), got %r"
-                             % (yval.shape,))
+            raise ValueError("expected y of shape (n_samples,), got %r" % (yval.shape,))
 
-    Xval = check_array(X, accept_sparse='csr')
+    Xval = check_array(X, accept_sparse="csr")
     if Xval.shape[0] != yval.shape[0]:
         raise ValueError(
-            "X.shape[0] and y.shape[0] should be the same, got"
-            " %r and %r instead." % (Xval.shape[0], yval.shape[0])
+            "X.shape[0] and y.shape[0] should be the same, got %r and %r instead."
+            % (Xval.shape[0], yval.shape[0])
         )
 
     # We had some issues with CSR matrices with unsorted indices (e.g. #1501),
@@ -488,8 +522,9 @@ def dump_svmlight_file(X, y, f, *, zero_based=True, comment=None,
     if query_id is not None:
         query_id = np.asarray(query_id)
         if query_id.shape[0] != y.shape[0]:
-            raise ValueError("expected query_id of shape (n_samples,), got %r"
-                             % (query_id.shape,))
+            raise ValueError(
+                "expected query_id of shape (n_samples,), got %r" % (query_id.shape,)
+            )
 
     one_based = not zero_based
 
