@@ -2,18 +2,26 @@
 Testing Recursive feature elimination
 """
 
+from operator import attrgetter
+
 import pytest
 import numpy as np
-from numpy.testing import assert_array_almost_equal, assert_array_equal
+from numpy.testing import assert_array_almost_equal, assert_array_equal, assert_allclose
 from scipy import sparse
 
+from sklearn.base import BaseEstimator, ClassifierMixin
+from sklearn.cross_decomposition import PLSCanonical, PLSRegression, CCA
 from sklearn.feature_selection import RFE, RFECV
 from sklearn.datasets import load_iris, make_friedman1
 from sklearn.metrics import zero_one_loss
-from sklearn.svm import SVC, SVR
+from sklearn.svm import SVC, SVR, LinearSVR
+from sklearn.linear_model import LogisticRegression
 from sklearn.ensemble import RandomForestClassifier
 from sklearn.model_selection import cross_val_score
 from sklearn.model_selection import GroupKFold
+from sklearn.compose import TransformedTargetRegressor
+from sklearn.pipeline import make_pipeline
+from sklearn.preprocessing import StandardScaler
 
 from sklearn.utils import check_random_state
 from sklearn.utils._testing import ignore_warnings
@@ -43,16 +51,16 @@ class MockClassifier:
     transform = predict
 
     def score(self, X=None, y=None):
-        return 0.
+        return 0.0
 
     def get_params(self, deep=True):
-        return {'foo_param': self.foo_param}
+        return {"foo_param": self.foo_param}
 
     def set_params(self, **params):
         return self
 
-    def _get_tags(self):
-        return {}
+    def _more_tags(self):
+        return {"allow_nan": True}
 
 
 def test_rfe_features_importance():
@@ -61,8 +69,7 @@ def test_rfe_features_importance():
     X = np.c_[iris.data, generator.normal(size=(len(iris.data), 6))]
     y = iris.target
 
-    clf = RandomForestClassifier(n_estimators=20,
-                                 random_state=generator, max_depth=2)
+    clf = RandomForestClassifier(n_estimators=20, random_state=generator, max_depth=2)
     rfe = RFE(estimator=clf, n_features_to_select=4, step=0.1)
     rfe.fit(X, y)
     assert len(rfe.ranking_) == X.shape[1]
@@ -104,6 +111,60 @@ def test_rfe():
     assert_array_almost_equal(X_r, X_r_sparse.toarray())
 
 
+def test_RFE_fit_score_params():
+    # Make sure RFE passes the metadata down to fit and score methods of the
+    # underlying estimator
+    class TestEstimator(BaseEstimator, ClassifierMixin):
+        def fit(self, X, y, prop=None):
+            if prop is None:
+                raise ValueError("fit: prop cannot be None")
+            self.svc_ = SVC(kernel="linear").fit(X, y)
+            self.coef_ = self.svc_.coef_
+            return self
+
+        def score(self, X, y, prop=None):
+            if prop is None:
+                raise ValueError("score: prop cannot be None")
+            return self.svc_.score(X, y)
+
+    X, y = load_iris(return_X_y=True)
+    with pytest.raises(ValueError, match="fit: prop cannot be None"):
+        RFE(estimator=TestEstimator()).fit(X, y)
+    with pytest.raises(ValueError, match="score: prop cannot be None"):
+        RFE(estimator=TestEstimator()).fit(X, y, prop="foo").score(X, y)
+
+    RFE(estimator=TestEstimator()).fit(X, y, prop="foo").score(X, y, prop="foo")
+
+
+@pytest.mark.parametrize("n_features_to_select", [-1, 2.1])
+def test_rfe_invalid_n_features_errors(n_features_to_select):
+    clf = SVC(kernel="linear")
+
+    iris = load_iris()
+    rfe = RFE(estimator=clf, n_features_to_select=n_features_to_select, step=0.1)
+    msg = f"n_features_to_select must be .+ Got {n_features_to_select}"
+    with pytest.raises(ValueError, match=msg):
+        rfe.fit(iris.data, iris.target)
+
+
+def test_rfe_percent_n_features():
+    # test that the results are the same
+    generator = check_random_state(0)
+    iris = load_iris()
+    X = np.c_[iris.data, generator.normal(size=(len(iris.data), 6))]
+    y = iris.target
+    # there are 10 features in the data. We select 40%.
+    clf = SVC(kernel="linear")
+    rfe_num = RFE(estimator=clf, n_features_to_select=4, step=0.1)
+    rfe_num.fit(X, y)
+
+    rfe_perc = RFE(estimator=clf, n_features_to_select=0.4, step=0.1)
+    rfe_perc.fit(X, y)
+
+    assert_array_equal(rfe_perc.ranking_, rfe_num.ranking_)
+    assert_array_equal(rfe_perc.support_, rfe_num.support_)
+
+
 def test_rfe_mockclassifier():
     generator = check_random_state(0)
     iris = load_iris()
@@ -124,13 +185,24 @@ def test_rfecv():
     generator = check_random_state(0)
     iris = load_iris()
     X = np.c_[iris.data, generator.normal(size=(len(iris.data), 6))]
-    y = list(iris.target)   # regression test: list should be supported
+    y = list(iris.target)  # regression test: list should be supported
 
     # Test using the score function
     rfecv = RFECV(estimator=SVC(kernel="linear"), step=1)
     rfecv.fit(X, y)
     # non-regression test for missing worst feature:
-    assert len(rfecv.grid_scores_) == X.shape[1]
+
+    # TODO: Remove in v1.2 when grid_scores_ is removed
+    msg = (
+        r"The `grid_scores_` attribute is deprecated in version 1\.0 in "
+        r"favor of `cv_results_` and will be removed in version 1\.2."
+    )
+    with pytest.warns(FutureWarning, match=msg):
+        assert len(rfecv.grid_scores_) == X.shape[1]
+
+    for key in rfecv.cv_results_.keys():
+        assert len(rfecv.cv_results_[key]) == X.shape[1]
+
     assert len(rfecv.ranking_) == X.shape[1]
     X_r = rfecv.transform(X)
 
@@ -152,18 +224,23 @@ def test_rfecv():
     assert_array_equal(X_r, iris.data)
 
     # Test using a scorer
-    scorer = get_scorer('accuracy')
+    scorer = get_scorer("accuracy")
     rfecv = RFECV(estimator=SVC(kernel="linear"), step=1, scoring=scorer)
     rfecv.fit(X, y)
     X_r = rfecv.transform(X)
     assert_array_equal(X_r, iris.data)
 
-    # Test fix on grid_scores
+    # Test fix on cv_results_
     def test_scorer(estimator, X, y):
         return 1.0
+
     rfecv = RFECV(estimator=SVC(kernel="linear"), step=1, scoring=test_scorer)
     rfecv.fit(X, y)
-    assert_array_equal(rfecv.grid_scores_, np.ones(len(rfecv.grid_scores_)))
+
+    # TODO: Remove in v1.2 when grid_scores_ is removed
+    with pytest.warns(FutureWarning, match=msg):
+        assert_array_equal(rfecv.grid_scores_, np.ones(rfecv.grid_scores_.shape))
+
     # In the event of cross validation score ties, the expected behavior of
     # RFECV is to return the FEWEST features that maximize the CV score.
     # Because test_scorer always returns 1.0 in this example, RFECV should
@@ -173,7 +250,14 @@ def test_rfecv():
     # Same as the first two tests, but with step=2
     rfecv = RFECV(estimator=SVC(kernel="linear"), step=2)
     rfecv.fit(X, y)
-    assert len(rfecv.grid_scores_) == 6
+
+    # TODO: Remove in v1.2 when grid_scores_ is removed
+    with pytest.warns(FutureWarning, match=msg):
+        assert len(rfecv.grid_scores_) == 6
+
+    for key in rfecv.cv_results_.keys():
+        assert len(rfecv.cv_results_[key]) == 6
+
     assert len(rfecv.ranking_) == X.shape[1]
     X_r = rfecv.transform(X)
     assert_array_equal(X_r, iris.data)
@@ -185,7 +269,7 @@ def test_rfecv():
     assert_array_equal(X_r_sparse.toarray(), iris.data)
 
     # Verifying that steps < 1 don't blow up.
-    rfecv_sparse = RFECV(estimator=SVC(kernel="linear"), step=.2)
+    rfecv_sparse = RFECV(estimator=SVC(kernel="linear"), step=0.2)
     X_sparse = sparse.csr_matrix(X)
     rfecv_sparse.fit(X_sparse, y)
     X_r_sparse = rfecv_sparse.transform(X_sparse)
@@ -196,13 +280,24 @@ def test_rfecv_mockclassifier():
     generator = check_random_state(0)
     iris = load_iris()
     X = np.c_[iris.data, generator.normal(size=(len(iris.data), 6))]
-    y = list(iris.target)   # regression test: list should be supported
+    y = list(iris.target)  # regression test: list should be supported
 
     # Test using the score function
     rfecv = RFECV(estimator=MockClassifier(), step=1)
     rfecv.fit(X, y)
     # non-regression test for missing worst feature:
-    assert len(rfecv.grid_scores_) == X.shape[1]
+
+    # TODO: Remove in v1.2 when grid_scores_ is removed
+    msg = (
+        r"The `grid_scores_` attribute is deprecated in version 1\.0 in "
+        r"favor of `cv_results_` and will be removed in version 1\.2."
+    )
+    with pytest.warns(FutureWarning, match=msg):
+        assert len(rfecv.grid_scores_) == X.shape[1]
+
+    for key in rfecv.cv_results_.keys():
+        assert len(rfecv.cv_results_[key]) == X.shape[1]
+
     assert len(rfecv.ranking_) == X.shape[1]
 
 
@@ -210,6 +305,7 @@ def test_rfecv_verbose_output():
     # Check verbose=1 is producing an output.
     from io import StringIO
     import sys
+
     sys.stdout = StringIO()
 
     generator = check_random_state(0)
@@ -225,33 +321,46 @@ def test_rfecv_verbose_output():
     assert len(verbose_output.readline()) > 0
 
 
-def test_rfecv_grid_scores_size():
+def test_rfecv_cv_results_size():
     generator = check_random_state(0)
     iris = load_iris()
     X = np.c_[iris.data, generator.normal(size=(len(iris.data), 6))]
-    y = list(iris.target)   # regression test: list should be supported
+    y = list(iris.target)  # regression test: list should be supported
 
     # Non-regression test for varying combinations of step and
     # min_features_to_select.
     for step, min_features_to_select in [[2, 1], [2, 2], [3, 3]]:
-        rfecv = RFECV(estimator=MockClassifier(), step=step,
-                      min_features_to_select=min_features_to_select)
+        rfecv = RFECV(
+            estimator=MockClassifier(),
+            step=step,
+            min_features_to_select=min_features_to_select,
+        )
         rfecv.fit(X, y)
 
-        score_len = np.ceil(
-            (X.shape[1] - min_features_to_select) / step) + 1
-        assert len(rfecv.grid_scores_) == score_len
+        score_len = np.ceil((X.shape[1] - min_features_to_select) / step) + 1
+
+        # TODO: Remove in v1.2 when grid_scores_ is removed
+        msg = (
+            r"The `grid_scores_` attribute is deprecated in version 1\.0 in "
+            r"favor of `cv_results_` and will be removed in version 1\.2."
+        )
+        with pytest.warns(FutureWarning, match=msg):
+            assert len(rfecv.grid_scores_) == score_len
+
+        for key in rfecv.cv_results_.keys():
+            assert len(rfecv.cv_results_[key]) == score_len
+
         assert len(rfecv.ranking_) == X.shape[1]
         assert rfecv.n_features_ >= min_features_to_select
 
 
 def test_rfe_estimator_tags():
-    rfe = RFE(SVC(kernel='linear'))
+    rfe = RFE(SVC(kernel="linear"))
     assert rfe._estimator_type == "classifier"
     # make sure that cross-validation is stratified
     iris = load_iris()
     score = cross_val_score(rfe, iris.data, iris.target)
-    assert score.min() > .7
+    assert score.min() > 0.7
 
 
 def test_rfe_min_step():
@@ -298,22 +407,24 @@ def test_number_of_subsets_of_features():
     n_features_to_select_list = [3, 3]
     step_list = [2, 3]
     for n_features, n_features_to_select, step in zip(
-            n_features_list, n_features_to_select_list, step_list):
+        n_features_list, n_features_to_select_list, step_list
+    ):
         generator = check_random_state(43)
         X = generator.normal(size=(100, n_features))
         y = generator.rand(100).round()
-        rfe = RFE(estimator=SVC(kernel="linear"),
-                  n_features_to_select=n_features_to_select, step=step)
+        rfe = RFE(
+            estimator=SVC(kernel="linear"),
+            n_features_to_select=n_features_to_select,
+            step=step,
+        )
         rfe.fit(X, y)
         # this number also equals to the maximum of ranking_
-        assert (np.max(rfe.ranking_) ==
-                     formula1(n_features, n_features_to_select, step))
-        assert (np.max(rfe.ranking_) ==
-                     formula2(n_features, n_features_to_select, step))
+        assert np.max(rfe.ranking_) == formula1(n_features, n_features_to_select, step)
+        assert np.max(rfe.ranking_) == formula2(n_features, n_features_to_select, step)
 
     # In RFECV, 'fit' calls 'RFE._fit'
     # 'number_of_subsets_of_features' of RFE
-    # = the size of 'grid_scores' of RFECV
+    # = the size of each score in 'cv_results_' of RFECV
     # = the number of iterations of the for loop before optimization #4534
 
     # RFECV, n_features_to_select = 1
@@ -330,10 +441,26 @@ def test_number_of_subsets_of_features():
         rfecv = RFECV(estimator=SVC(kernel="linear"), step=step)
         rfecv.fit(X, y)
 
-        assert (rfecv.grid_scores_.shape[0] ==
-                     formula1(n_features, n_features_to_select, step))
-        assert (rfecv.grid_scores_.shape[0] ==
-                     formula2(n_features, n_features_to_select, step))
+        # TODO: Remove in v1.2 when grid_scores_ is removed
+        msg = (
+            r"The `grid_scores_` attribute is deprecated in version 1\.0 in "
+            r"favor of `cv_results_` and will be removed in version 1\.2."
+        )
+        with pytest.warns(FutureWarning, match=msg):
+            assert len(rfecv.grid_scores_) == formula1(
+                n_features, n_features_to_select, step
+            )
+            assert len(rfecv.grid_scores_) == formula2(
+                n_features, n_features_to_select, step
+            )
+
+        for key in rfecv.cv_results_.keys():
+            assert len(rfecv.cv_results_[key]) == formula1(
+                n_features, n_features_to_select, step
+            )
+            assert len(rfecv.cv_results_[key]) == formula2(
+                n_features, n_features_to_select, step
+            )
 
 
 def test_rfe_cv_n_jobs():
@@ -342,15 +469,31 @@ def test_rfe_cv_n_jobs():
     X = np.c_[iris.data, generator.normal(size=(len(iris.data), 6))]
     y = iris.target
 
-    rfecv = RFECV(estimator=SVC(kernel='linear'))
+    rfecv = RFECV(estimator=SVC(kernel="linear"))
     rfecv.fit(X, y)
     rfecv_ranking = rfecv.ranking_
-    rfecv_grid_scores = rfecv.grid_scores_
+
+    # TODO: Remove in v1.2 when grid_scores_ is removed
+    msg = (
+        r"The `grid_scores_` attribute is deprecated in version 1\.0 in "
+        r"favor of `cv_results_` and will be removed in version 1\.2."
+    )
+    with pytest.warns(FutureWarning, match=msg):
+        rfecv_grid_scores = rfecv.grid_scores_
+
+    rfecv_cv_results_ = rfecv.cv_results_
 
     rfecv.set_params(n_jobs=2)
     rfecv.fit(X, y)
     assert_array_almost_equal(rfecv.ranking_, rfecv_ranking)
-    assert_array_almost_equal(rfecv.grid_scores_, rfecv_grid_scores)
+
+    # TODO: Remove in v1.2 when grid_scores_ is removed
+    with pytest.warns(FutureWarning, match=msg):
+        assert_array_almost_equal(rfecv.grid_scores_, rfecv_grid_scores)
+
+    assert rfecv_cv_results_.keys() == rfecv.cv_results_.keys()
+    for key in rfecv_cv_results_.keys():
+        assert rfecv_cv_results_[key] == pytest.approx(rfecv.cv_results_[key])
 
 
 def test_rfe_cv_groups():
@@ -364,17 +507,55 @@ def test_rfe_cv_groups():
     est_groups = RFECV(
         estimator=RandomForestClassifier(random_state=generator),
         step=1,
-        scoring='accuracy',
-        cv=GroupKFold(n_splits=2)
+        scoring="accuracy",
+        cv=GroupKFold(n_splits=2),
     )
     est_groups.fit(X, y, groups=groups)
     assert est_groups.n_features_ > 0
 
 
-@pytest.mark.parametrize("cv", [
-    None,
-    5
-])
+@pytest.mark.parametrize(
+    "importance_getter", [attrgetter("regressor_.coef_"), "regressor_.coef_"]
+)
+@pytest.mark.parametrize("selector, expected_n_features", [(RFE, 5), (RFECV, 4)])
+def test_rfe_wrapped_estimator(importance_getter, selector, expected_n_features):
+    # Non-regression test for
+    # https://github.com/scikit-learn/scikit-learn/issues/15312
+    X, y = make_friedman1(n_samples=50, n_features=10, random_state=0)
+    estimator = LinearSVR(random_state=0)
+
+    log_estimator = TransformedTargetRegressor(
+        regressor=estimator, func=np.log, inverse_func=np.exp
+    )
+
+    selector = selector(log_estimator, importance_getter=importance_getter)
+    sel = selector.fit(X, y)
+    assert sel.support_.sum() == expected_n_features
+
+
+@pytest.mark.parametrize(
+    "importance_getter, err_type",
+    [
+        ("auto", ValueError),
+        ("random", AttributeError),
+        (lambda x: x.importance, AttributeError),
+        ([0], ValueError),
+    ],
+)
+@pytest.mark.parametrize("Selector", [RFE, RFECV])
+def test_rfe_importance_getter_validation(importance_getter, err_type, Selector):
+    X, y = make_friedman1(n_samples=50, n_features=10, random_state=42)
+    estimator = LinearSVR()
+    log_estimator = TransformedTargetRegressor(
+        regressor=estimator, func=np.log, inverse_func=np.exp
+    )
+
+    with pytest.raises(err_type):
+        model = Selector(log_estimator, importance_getter=importance_getter)
+        model.fit(X, y)
+
+
+@pytest.mark.parametrize("cv", [None, 5])
 def test_rfe_allow_nan_inf_in_x(cv):
     iris = load_iris()
     X = iris.data
@@ -393,13 +574,57 @@ def test_rfe_allow_nan_inf_in_x(cv):
     rfe.transform(X)
 
 
-@pytest.mark.parametrize('ClsRFE', [
-    RFE,
-    RFECV
-    ])
+def test_w_pipeline_2d_coef_():
+    pipeline = make_pipeline(StandardScaler(), LogisticRegression())
+
+    data, y = load_iris(return_X_y=True)
+    sfm = RFE(
+        pipeline,
+        n_features_to_select=2,
+        importance_getter="named_steps.logisticregression.coef_",
+    )
+
+    sfm.fit(data, y)
+    assert sfm.transform(data).shape[1] == 2
+
+
+def test_rfecv_std_and_mean():
+    generator = check_random_state(0)
+    iris = load_iris()
+    X = np.c_[iris.data, generator.normal(size=(len(iris.data), 6))]
+    y = iris.target
+
+    rfecv = RFECV(estimator=SVC(kernel="linear"))
+    rfecv.fit(X, y)
+    n_split_keys = len(rfecv.cv_results_) - 2
+    split_keys = [f"split{i}_test_score" for i in range(n_split_keys)]
+
+    cv_scores = np.asarray([rfecv.cv_results_[key] for key in split_keys])
+    expected_mean = np.mean(cv_scores, axis=0)
+    expected_std = np.std(cv_scores, axis=0)
+
+    assert_allclose(rfecv.cv_results_["mean_test_score"], expected_mean)
+    assert_allclose(rfecv.cv_results_["std_test_score"], expected_std)
+
+
+@pytest.mark.parametrize("ClsRFE", [RFE, RFECV])
 def test_multioutput(ClsRFE):
     X = np.random.normal(size=(10, 3))
     y = np.random.randint(2, size=(10, 2))
     clf = RandomForestClassifier(n_estimators=5)
     rfe_test = ClsRFE(clf)
     rfe_test.fit(X, y)
+
+
+@pytest.mark.parametrize("ClsRFE", [RFE, RFECV])
+@pytest.mark.parametrize("PLSEstimator", [CCA, PLSCanonical, PLSRegression])
+def test_rfe_pls(ClsRFE, PLSEstimator):
+    """Check the behaviour of RFE with PLS estimators.
+
+    Non-regression test for:
+    https://github.com/scikit-learn/scikit-learn/issues/12410
+    """
+    X, y = make_friedman1(n_samples=50, n_features=10, random_state=0)
+    estimator = PLSEstimator(n_components=1)
+    selector = ClsRFE(estimator, step=1).fit(X, y)
+    assert selector.score(X, y) > 0.5
